## Download histogram data from ebird.org by clicking 
##  Explore Data > Nevada Hotspots > select appropriate hotspots (3) 
##  To download the histogram data, see the link below the histogram.

## Plot using
library(ggplot2)

## Data is a tab-delimited text file.

######################    EXAMPLE 1   ##########################
##
# Get some header info:
SS=read.delim("UNR-eBird-BarChart-data", skip=13, nrows=1, header=FALSE)
SS=as.integer(SS[1,-c(1,50)])
SS ## Sample Size (# checklists) for each quarter-month
length(SS)

# Label weeks for plotting...
SS=data.frame(SampleSize=SS, Week=1:48)
# ... and plot as barchart (see http://docs.ggplot2.org/current/)
ggplot(SS, aes(factor(Week), SampleSize)) +
  geom_bar(stat = "identity", fill="darkgreen") +
  geom_hline(yintercept=0)


######################    EXAMPLE 2   ##########################
##
## Load the histogram data starting at line 15, omit last column
UNR=read.delim("UNR-eBird-BarChart-data", skip=15, header=FALSE, colClasses=c(rep(NA,49),"NULL"))
colnames(UNR) <- c("Species",paste(rep(month.abb,each=4),rep(".W",48),rep(1:4,12),sep=''))

## Convert from proportion of checklists with that species, to total checklists
UNR2=UNR
attach(SS)
for(i in 1:nrow(UNR)) {
  UNR2[i,-1] <- UNR[i,-1]*SampleSize
}
detach(SS)
UNR2[,-1] <- as.integer(UNR2[,-1])
head(UNR2)

## Do the data make sense?
edit(UNR2)
unique(sort(as.matrix(UNR2[,-1])))



